@@ -280,8 +280,8 @@ quality_to_xcode(struct media_quality *quality)
 static int
 encoding_reset(struct media_quality *quality)
 {
+  struct transcode_encode_setup_args encode_args = { 0 };
   struct output_quality_subscription *subscription;
-  struct decode_ctx *decode_ctx;
   enum transcode_profile profile;
   int i;
 
@@ -293,8 +293,8 @@ encoding_reset(struct media_quality *quality)
       return -1;
     }
 
-  decode_ctx = transcode_decode_setup_raw(profile, quality);
-  if (!decode_ctx)
+  encode_args.src_ctx = transcode_decode_setup_raw(profile, quality);
+  if (!encode_args.src_ctx)
     {
       DPRINTF(E_LOG, L_PLAYER, "Could not create subscription decoding context (profile %d)\n", profile);
       return -1;
@@ -309,15 +309,16 @@ encoding_reset(struct media_quality *quality)
       if (quality_is_equal(quality, &subscription->quality))
 	continue; // No resampling required
 
-      profile = quality_to_xcode(&subscription->quality);
-      if (profile != XCODE_UNKNOWN)
-	subscription->encode_ctx = transcode_encode_setup(profile, &subscription->quality, decode_ctx, NULL, 0, 0);
+      encode_args.profile = quality_to_xcode(&subscription->quality);
+      encode_args.quality = &subscription->quality;
+      if (encode_args.profile != XCODE_UNKNOWN)
+	subscription->encode_ctx = transcode_encode_setup(encode_args);
       else
 	DPRINTF(E_LOG, L_PLAYER, "Could not setup resampling to %d/%d/%d for output\n",
 	  subscription->quality.sample_rate, subscription->quality.bits_per_sample, subscription->quality.channels);
     }
 
-  transcode_decode_cleanup(&decode_ctx);
+  transcode_decode_cleanup(&encode_args.src_ctx);
 
   return 0;
 }
@@ -389,6 +390,43 @@ buffer_drain(struct output_buffer *obuf)
     }
 }
 
+static struct output_buffer *
+buffer_copy(struct output_buffer *obuf)
+{
+  struct output_buffer *copy;
+  int i;
+
+  if (!obuf)
+    return NULL;
+
+  CHECK_NULL(L_PLAYER, copy = malloc(sizeof(struct output_buffer)));
+
+  memcpy(copy, obuf, sizeof(struct output_buffer));
+
+  for (i = 0; obuf->data[i].buffer; i++)
+    {
+      CHECK_NULL(L_PLAYER, copy->data[i].evbuf = evbuffer_new());
+      evbuffer_add(copy->data[i].evbuf, obuf->data[i].buffer, obuf->data[i].bufsize);
+      copy->data[i].buffer = evbuffer_pullup(copy->data[i].evbuf, -1);
+    }
+
+  return copy;
+}
+
+static void
+buffer_free(struct output_buffer *obuf)
+{
+  int i;
+
+  if (!obuf)
+    return;
+
+  for (i = 0; obuf->data[i].buffer; i++)
+    evbuffer_free(obuf->data[i].evbuf);
+
+  free(obuf);
+}
+
 static void
 device_list_sort(void)
 {
@@ -467,6 +505,16 @@ metadata_cb_prepare(void *arg)
   event_active(metadata->ev, 0, 0);
 }
 
+static void
+metadata_free(struct output_metadata *metadata)
+{
+  if (!metadata)
+    return;
+  if (metadata->ev)
+    event_free(metadata->ev);
+  free(metadata);
+}
+
 static void
 metadata_send(enum output_types type, uint32_t item_id, bool startup, output_metadata_finalize_cb cb)
 {
@@ -689,6 +737,23 @@ outputs_cb(int callback_id, uint64_t device_id, enum output_device_state state)
   event_active(outputs_deferredev, 0, 0);
 }
 
+void
+outputs_metadata_free(struct output_metadata *metadata)
+{
+  metadata_free(metadata);
+}
+
+struct output_buffer *
+outputs_buffer_copy(struct output_buffer *buffer)
+{
+  return buffer_copy(buffer);
+}
+
+void
+outputs_buffer_free(struct output_buffer *buffer)
+{
+  buffer_free(buffer);
+}
 
 /* ---------------------------- Called by player ---------------------------- */
 
