@@ -1,36 +1,23 @@
-import { createApp } from 'vue'
-import i18n from './i18n'
-import store from './store'
-import { router } from './router'
-import VueProgressBar from '@aacassandra/vue3-progressbar'
+import './mystyles.scss'
+import App from './App.vue'
 import VueClickAway from 'vue3-click-away'
 import VueLazyLoad from 'vue3-lazyload'
-import VueScrollTo from 'vue-scrollto'
-import mdiVue from 'mdi-vue/v3'
+import VueProgressBar from '@aacassandra/vue3-progressbar'
+import { createApp } from 'vue'
+import { createPinia } from 'pinia'
 import { filters } from './filter'
+import i18n from './i18n'
 import { icons } from './icons'
-import App from './App.vue'
-
-import './mystyles.scss'
-import '@vueform/slider/themes/default.css'
+import mdiVue from 'mdi-vue/v3'
+import { router } from './router'
 
 const app = createApp(App)
-  .use(store)
+  .use(createPinia())
   .use(router)
-  .use(VueProgressBar, {
-    color: 'hsl(204, 86%, 53%)',
-    failedColor: 'red',
-    height: '1px'
-  })
+  .use(VueProgressBar)
   .use(VueClickAway)
-  .use(VueLazyLoad, {
-    // Do not log errors, if image does not exist
-    log: false
-  })
-  .use(VueScrollTo)
-  .use(mdiVue, {
-    icons: icons
-  })
+  .use(VueLazyLoad, { log: false })
+  .use(mdiVue, { icons })
   .use(i18n)
 
 app.config.globalProperties.$filters = filters
